pub struct OlError {
pub code: &'static str,
pub message: String,
pub suggestion: Option<String>,
pub docs_url: Option<String>,
}Expand description
A structured, user-facing error with an OL-XXXX code.
Display format (D-06/D-07)
Error: {message} (OL-XXXX)
Suggestion: {actionable text}
Docs: {url}Fields
code: &'static strThe OL-XXXX error code (e.g. “OL-1001”).
message: StringHuman-readable, actionable error description.
suggestion: Option<String>Optional suggestion for how to fix the error.
docs_url: Option<String>Optional link to documentation for this error code.
Implementations
Sourceimpl OlError
impl OlError
Sourcepub fn new(code: &'static str, message: impl Into<String>) -> Self
pub fn new(code: &'static str, message: impl Into<String>) -> Self
Create a new error with the given code and message.
Sourcepub fn with_suggestion(self, s: impl Into<String>) -> Self
pub fn with_suggestion(self, s: impl Into<String>) -> Self
Attach a suggestion to this error.
Sourcepub fn bug_report(message: impl Into<String>) -> Self
pub fn bug_report(message: impl Into<String>) -> Self
Build a “bug report” error pre-filled with a GitHub issue URL.
Use this for unexpected internal errors that indicate a bug in openlatch.