EventLoggerHandle

Struct EventLoggerHandle 

pub struct EventLoggerHandle { /* private fields */ }
Owns the background writer task. MUST be held until shutdown.

Implementations

Source

impl EventLoggerHandle

pub async fn shutdown(self)

Wait for the background writer to drain and exit.

The caller must drop (or let go of) the EventLogger sender BEFORE calling this method, otherwise the writer task will block waiting for more events.